## 0.1.7 (2023-10-13)

### Feat

- add browser-automator (#21)

### Fix

- **makefile**: bump_version

## 0.1.6 (2023-10-11)

### Feat

- add commitizen
- **cmd**: enable cdp logging (#18)
- **github-actions**: improve ci_windows.yml
- **release**: 0.1.5
- **github-actions**: add ci_windows.yml (#14)
- **release**: 0.1.4
- **release**: 0.1.3
- **release**: 0.1.1
- **release**: 0.1.0
- initial public release (#1)
- initial public release

### Fix

- cyclic imports
- deserialize task in browser storage (#11)
- **github-actions**: remove pr_agent.yml
